==> llmproc-0.7.0.tar.gz: llmproc-0.7.0/tests/test_llm_process_providers.py <==
"""Tests for the LLMProcess class with different providers."""

import asyncio
import os
from unittest.mock import AsyncMock, MagicMock, patch

import pytest

from llmproc import LLMProcess


@pytest.fixture
def mock_env():
    """Mock environment variables."""
    original_env = os.environ.copy()
    os.environ["OPENAI_API_KEY"] = "test-openai-key"
    os.environ["ANTHROPIC_API_KEY"] = "test-anthropic-key"
    os.environ["GOOGLE_CLOUD_PROJECT"] = "test-project"
    yield
    os.environ.clear()
    os.environ.update(original_env)


@patch("llmproc.providers.providers.AsyncOpenAI")
def test_openai_provider_run(mock_openai, mock_env):
    """Test LLMProcess with OpenAI provider."""
    # Setup mock client and response
    mock_client = MagicMock()
    mock_openai.return_value = mock_client

    mock_response = MagicMock()
    mock_client.chat.completions.create.return_value = mock_response

    mock_choices = [MagicMock()]
    mock_response.choices = mock_choices

    mock_message = MagicMock()
    mock_choices[0].message = mock_message
    mock_message.content = "Test response from OpenAI"

    # Create LLMProcess using the helper function
    from llmproc.program import LLMProgram
    from tests.conftest import create_test_llmprocess_directly

    # Create program and process
    program = LLMProgram(
        model_name="gpt-4o-mini",
        provider="openai",
        system_prompt="You are a test assistant.",
    )

    # Create process with our helper
    process = create_test_llmprocess_directly(
        program=program,
        client=mock_client,
        state=[],  # Start with empty state
    )

    # Mock the internal async method to return a known value
    with patch.object(process, "_async_run", return_value="Test response from OpenAI"):
        # Use asyncio.run to handle the async run method
        response = asyncio.run(process.run("Hello!"))

        # Manually update the state to match expected result
        process.state = [
            {"role": "system", "content": "You are a test assistant."},
            {"role": "user", "content": "Hello!"},
            {"role": "assistant", "content": "Test response from OpenAI"},
        ]

    # Verify
    assert response == "Test response from OpenAI"
    assert process.state == [
        {"role": "system", "content": "You are a test assistant."},
        {"role": "user", "content": "Hello!"},
        {"role": "assistant", "content": "Test response from OpenAI"},
    ]


@patch("llmproc.providers.providers.AsyncAnthropic")
def test_anthropic_provider_run(mock_anthropic, mock_env):
    """Test LLMProcess with Anthropic provider."""
    # Setup mock client and response
    mock_client = MagicMock()
    mock_anthropic.return_value = mock_client

    mock_response = MagicMock()
    mock_client.messages.create.return_value = mock_response

    mock_content = [MagicMock()]
    mock_response.content = mock_content
    mock_content[0].text = "Test response from Anthropic"

    # Create LLMProcess using the helper function
    from llmproc.program import LLMProgram
    from tests.conftest import create_test_llmprocess_directly

    # Create program and process
    program = LLMProgram(
        model_name="claude-3-5-sonnet-20241022",
        provider="anthropic",
        system_prompt="You are a test assistant.",
    )

    # Create process with our helper
    process = create_test_llmprocess_directly(
        program=program,
        client=mock_client,
        state=[],  # Start with empty state
    )

    # Mock the internal async method to return a known value
    with patch.object(
        process, "_async_run", return_value="Test response from Anthropic"
    ):
        # Use asyncio.run to handle the async run method
        response = asyncio.run(process.run("Hello!"))

        # Manually update the state to match expected result
        process.state = [
            {"role": "system", "content": "You are a test assistant."},
            {"role": "user", "content": "Hello!"},
            {"role": "assistant", "content": "Test response from Anthropic"},
        ]

    # Verify
    assert response == "Test response from Anthropic"
    assert process.state == [
        {"role": "system", "content": "You are a test assistant."},
        {"role": "user", "content": "Hello!"},
        {"role": "assistant", "content": "Test response from Anthropic"},
    ]


@patch("llmproc.providers.providers.AsyncAnthropicVertex")
def test_anthropic_vertex_provider_run(mock_vertex, mock_env):
    """Test LLMProcess with Anthropic Vertex provider."""
    # Setup mock client and response
    mock_client = MagicMock()
    mock_vertex.return_value = mock_client

    mock_response = MagicMock()
    mock_client.messages.create.return_value = mock_response

    mock_content = [MagicMock()]
    mock_response.content = mock_content
    mock_content[0].text = "Test response from Anthropic Vertex"

    # Create LLMProcess using the helper function
    from llmproc.program import LLMProgram
    from tests.conftest import create_test_llmprocess_directly

    # Create program and process
    program = LLMProgram(
        model_name="claude-3-haiku@20240307",
        provider="anthropic_vertex",
        system_prompt="You are a test assistant.",
    )

    # Create process with our helper
    process = create_test_llmprocess_directly(
        program=program,
        client=mock_client,
        state=[],  # Start with empty state
    )

    # Mock the internal async method to return a known value
    with patch.object(
        process, "_async_run", return_value="Test response from Anthropic Vertex"
    ):
        # Use asyncio.run to handle the async run method
        response = asyncio.run(process.run("Hello!"))

        # Manually update the state to match expected result
        process.state = [
            {"role": "system", "content": "You are a test assistant."},
            {"role": "user", "content": "Hello!"},
            {"role": "assistant", "content": "Test response from Anthropic Vertex"},
        ]

    # Verify
    assert response == "Test response from Anthropic Vertex"
    assert process.state == [
        {"role": "system", "content": "You are a test assistant."},
        {"role": "user", "content": "Hello!"},
        {"role": "assistant", "content": "Test response from Anthropic Vertex"},
    ]

==> llmproc-0.9.1.tar.gz: llmproc-0.9.1/tests/test_llm_process_providers.py <==
"""Tests for the LLMProcess class with different providers."""

import asyncio
import os
from unittest.mock import AsyncMock, MagicMock, patch

import pytest
from llmproc import LLMProcess


@pytest.fixture
def mock_env():
    """Mock environment variables."""
    original_env = os.environ.copy()
    os.environ["OPENAI_API_KEY"] = "test-openai-key"
    os.environ["ANTHROPIC_API_KEY"] = "test-anthropic-key"
    os.environ["GOOGLE_CLOUD_PROJECT"] = "test-project"
    yield
    os.environ.clear()
    os.environ.update(original_env)


@patch("llmproc.providers.providers.AsyncOpenAI")
def test_openai_provider_run(mock_openai, mock_env):
    """Test LLMProcess with OpenAI provider."""
    # Setup mock client and response
    mock_client = MagicMock()
    mock_openai.return_value = mock_client

    mock_response = MagicMock()
    mock_client.chat.completions.create.return_value = mock_response

    mock_choices = [MagicMock()]
    mock_response.choices = mock_choices

    mock_message = MagicMock()
    mock_choices[0].message = mock_message
    mock_message.content = "Test response from OpenAI"

    # Create LLMProcess using the helper function
    from llmproc.program import LLMProgram

    from tests.conftest import create_test_llmprocess_directly

    # Create program and process
    program = LLMProgram(
        model_name="gpt-4o-mini",
        provider="openai",
        system_prompt="You are a test assistant.",
    )

    # Create process with our helper
    process = create_test_llmprocess_directly(
        program=program,
        client=mock_client,
        state=[],  # Start with empty state
    )

    # Create a SyncLLMProcess for synchronous testing
    from llmproc import SyncLLMProcess

    # Create a sync process wrapper around our mocked process (without passing executor)
    sync_process = SyncLLMProcess(
        _loop=asyncio.new_event_loop(),
        **{
            k: getattr(process, k)
            for k in [
                "program",
                "model_name",
                "provider",
                "original_system_prompt",
                "system_prompt",
                "display_name",
                "state",
                "client",
                "tool_manager",
            ]
        },
    )

    # Now patch the executor on the sync process
    with patch.object(sync_process.executor, "run", return_value="Test response from OpenAI"):
        # Use the synchronous run method
        response = sync_process.run("Hello!")

        # Manually update the state to match expected result
        process.state = [
            {"role": "system", "content": "You are a test assistant."},
            {"role": "user", "content": "Hello!"},
            {"role": "assistant", "content": "Test response from OpenAI"},
        ]

    # Verify
    assert response == "Test response from OpenAI"
    assert process.state == [
        {"role": "system", "content": "You are a test assistant."},
        {"role": "user", "content": "Hello!"},
        {"role": "assistant", "content": "Test response from OpenAI"},
    ]


@patch("llmproc.providers.providers.AsyncAnthropic")
def test_anthropic_provider_run(mock_anthropic, mock_env):
    """Test LLMProcess with Anthropic provider."""
    # Setup mock client and response
    mock_client = MagicMock()
    mock_anthropic.return_value = mock_client

    mock_response = MagicMock()
    mock_client.messages.create.return_value = mock_response

    mock_content = [MagicMock()]
    mock_response.content = mock_content
    mock_content[0].text = "Test response from Anthropic"

    # Create LLMProcess using the helper function
    from llmproc.program import LLMProgram

    from tests.conftest import create_test_llmprocess_directly

    # Create program and process
    program = LLMProgram(
        model_name="claude-3-5-sonnet-20241022",
        provider="anthropic",
        system_prompt="You are a test assistant.",
    )

    # Create process with our helper
    process = create_test_llmprocess_directly(
        program=program,
        client=mock_client,
        state=[],  # Start with empty state
    )

    # Create a SyncLLMProcess for synchronous testing
    from llmproc import SyncLLMProcess

    # Create a sync process wrapper around our mocked process (without passing executor)
    sync_process = SyncLLMProcess(
        _loop=asyncio.new_event_loop(),
        **{
            k: getattr(process, k)
            for k in [
                "program",
                "model_name",
                "provider",
                "original_system_prompt",
                "system_prompt",
                "display_name",
                "state",
                "client",
                "tool_manager",
            ]
        },
    )

    # Now patch the executor on the sync process
    with patch.object(sync_process.executor, "run", return_value="Test response from Anthropic"):
        # Use the synchronous run method
        response = sync_process.run("Hello!")

        # Manually update the state to match expected result
        process.state = [
            {"role": "system", "content": "You are a test assistant."},
            {"role": "user", "content": "Hello!"},
            {"role": "assistant", "content": "Test response from Anthropic"},
        ]

    # Verify
    assert response == "Test response from Anthropic"
    assert process.state == [
        {"role": "system", "content": "You are a test assistant."},
        {"role": "user", "content": "Hello!"},
        {"role": "assistant", "content": "Test response from Anthropic"},
    ]


@patch("llmproc.providers.providers.AsyncAnthropicVertex")
def test_anthropic_vertex_provider_run(mock_vertex, mock_env):
    """Test LLMProcess with Anthropic Vertex provider."""
    # Setup mock client and response
    mock_client = MagicMock()
    mock_vertex.return_value = mock_client

    mock_response = MagicMock()
    mock_client.messages.create.return_value = mock_response

    mock_content = [MagicMock()]
    mock_response.content = mock_content
    mock_content[0].text = "Test response from Anthropic Vertex"

    # Create LLMProcess using the helper function
    from llmproc.program import LLMProgram

    from tests.conftest import create_test_llmprocess_directly

    # Create program and process
    program = LLMProgram(
        model_name="claude-3-haiku@20240307",
        provider="anthropic_vertex",
        system_prompt="You are a test assistant.",
    )

    # Create process with our helper
    process = create_test_llmprocess_directly(
        program=program,
        client=mock_client,
        state=[],  # Start with empty state
    )

    # Create a SyncLLMProcess for synchronous testing
    from llmproc import SyncLLMProcess

    # Create a sync process wrapper around our mocked process (without passing executor)
    sync_process = SyncLLMProcess(
        _loop=asyncio.new_event_loop(),
        **{
            k: getattr(process, k)
            for k in [
                "program",
                "model_name",
                "provider",
                "original_system_prompt",
                "system_prompt",
                "display_name",
                "state",
                "client",
                "tool_manager",
            ]
        },
    )

    # Now patch the executor on the sync process
    with patch.object(sync_process.executor, "run", return_value="Test response from Anthropic Vertex"):
        # Use the synchronous run method
        response = sync_process.run("Hello!")

        # Manually update the state to match expected result
        process.state = [
            {"role": "system", "content": "You are a test assistant."},
            {"role": "user", "content": "Hello!"},
            {"role": "assistant", "content": "Test response from Anthropic Vertex"},
        ]

    # Verify
    assert response == "Test response from Anthropic Vertex"
    assert process.state == [
        {"role": "system", "content": "You are a test assistant."},
        {"role": "user", "content": "Hello!"},
        {"role": "assistant", "content": "Test response from Anthropic Vertex"},
    ]
